@@ -47,23 +47,25 @@ module Kitchen
         is_file_root: false,
         local_salt_root: nil,
         omnibus_cachier: false,
+        pillar_env: nil,
         pillars_from_directories: [],
         pip_bin: 'pip',
         pip_editable: false,
         pip_extra_index_url: [],
-        pip_index_url: 'https://pypi.python.org/simple/',
+        pip_index_url: 'https://pypi.org/simple/',
         pip_pkg: 'salt==%s',
         remote_states: nil,
         require_chef: true,
-        salt_apt_repo_key: 'https://repo.saltstack.com/apt/ubuntu/16.04/amd64/latest/SALTSTACK-GPG-KEY.pub',
-        salt_apt_repo: 'https://repo.saltstack.com/apt/ubuntu/16.04/amd64/',
+        salt_apt_repo_key: 'https://repo.saltproject.io/apt/ubuntu/16.04/amd64/latest/SALTSTACK-GPG-KEY.pub',
+        salt_apt_repo: 'https://repo.saltproject.io/apt/ubuntu/16.04/amd64',
         salt_bootstrap_options: '',
-        salt_bootstrap_url: 'https://bootstrap.saltstack.com',
+        salt_bootstrap_url: 'https://bootstrap.saltproject.io',
         salt_config: '/etc/salt',
         salt_copy_filter: [],
         salt_env: 'base',
         salt_file_root: '/srv/salt',
         salt_force_color: false,
+        salt_enable_color: true,
         salt_install: 'bootstrap',
         salt_minion_config_dropin_files: [],
         salt_minion_config_template: nil,
@@ -75,20 +77,21 @@ module Kitchen
         salt_spm_root: '/srv/spm',
         salt_state_top: '/srv/salt/top.sls',
         salt_version: 'latest',
-        salt_yum_repo_key: 'https://repo.saltstack.com/yum/redhat/$releasever/$basearch/archive/%s/SALTSTACK-GPG-KEY.pub',
-        salt_yum_repo_latest: 'https://repo.saltstack.com/yum/redhat/salt-repo-latest-2.el7.noarch.rpm',
-        salt_yum_repo: 'https://repo.saltstack.com/yum/redhat/$releasever/$basearch/archive/%s',
-        salt_yum_rpm_key: 'https://repo.saltstack.com/yum/redhat/7/x86_64/archive/%s/SALTSTACK-GPG-KEY.pub',
+        salt_yum_repo_key: 'https://repo.saltproject.io/yum/redhat/$releasever/$basearch/archive/%s/SALTSTACK-GPG-KEY.pub',
+        salt_yum_repo_latest: 'https://repo.saltproject.io/yum/redhat/salt-repo-latest-2.el7.noarch.rpm',
+        salt_yum_repo: 'https://repo.saltproject.io/yum/redhat/$releasever/$basearch/archive/%s',
+        salt_yum_rpm_key: 'https://repo.saltproject.io/yum/redhat/7/x86_64/archive/%s/SALTSTACK-GPG-KEY.pub',
         state_collection: false,
         state_top_from_file: false,
         state_top: {},
         vendor_path: nil,
-        vendor_repo: {}
+        vendor_repo: {},
+        run_salt_call: true
       }.freeze
 
       WIN_DEFAULT_CONFIG = {
         chef_bootstrap_url: 'https://omnitruck.chef.io/install.ps1',
-        salt_bootstrap_url: 'https://raw.githubusercontent.com/saltstack/salt-bootstrap/develop/bootstrap-salt.ps1'
+        salt_bootstrap_url: 'https://winbootstrap.saltproject.io/develop'
       }.freeze
 
       # salt-call version that supports the undocumented --retcode-passthrough command
@@ -105,6 +108,7 @@ module Kitchen
       end
 
       def install_command
+        return unless config[:salt_install]
         unless config[:salt_install] == 'pip' || config[:install_after_init_environment]
           setup_salt
         end
@@ -122,6 +126,7 @@ module Kitchen
             #{config[:prepare_salt_environment]}
           PREPARE
         end
+        return cmd unless config[:salt_install]
         if config[:salt_install] == 'pip' || config[:install_after_init_environment]
           cmd << setup_salt
         end
@@ -207,6 +212,7 @@ module Kitchen
       end
 
       def prepare_install
+        return unless config[:salt_install]
         salt_version = config[:salt_version]
         if config[:salt_install] == 'pip'
           debug('Using pip to install')
@@ -258,22 +264,33 @@ module Kitchen
 
         cmd = ''
         if windows_os?
-          salt_call = "c:\\salt\\salt-call.bat"
           salt_config_path = config[:salt_config]
           cmd << "(get-content #{os_join(config[:root_path], salt_config_path, 'minion')}) -replace '\\$env:TEMP', $env:TEMP | set-content #{os_join(config[:root_path], salt_config_path, 'minion')} ;"
         else
           # install/update dependencies
           cmd << sudo("chmod +x #{config[:root_path]}/*.sh;")
           cmd << sudo("#{config[:root_path]}/dependencies.sh;")
-          cmd << sudo("#{config[:root_path]}/gpgkey.sh;")
+          cmd << sudo("#{config[:root_path]}/gpgkey.sh;") if config[:gpg_key]
           salt_config_path = config[:salt_config]
-          salt_call = 'salt-call'
         end
-        cmd << sudo("#{salt_call} --state-output=changes --config-dir=#{os_join(config[:root_path], salt_config_path)} state.highstate")
+
+        if config[:pre_salt_command]
+          cmd << "#{config[:pre_salt_command]} && "
+        end
+        cmd << sudo("#{salt_call}")
+        state_output = config[:salt_minion_extra_config][:state_output]
+        if state_output
+          cmd << " --state-output=#{state_output}"
+        else
+          cmd << " --state-output=changes"
+        end
+        cmd << " --config-dir=#{os_join(config[:root_path], salt_config_path)}"
+        cmd << " state.highstate"
         cmd << " --log-level=#{config[:log_level]}" if config[:log_level]
         cmd << " --id=#{config[:salt_minion_id]}" if config[:salt_minion_id]
         cmd << " test=#{config[:dry_run]}" if config[:dry_run]
         cmd << ' --force-color' if config[:salt_force_color]
+        cmd << ' --no-color' if not config[:salt_enable_color]
         if "#{salt_version}" > RETCODE_VERSION || salt_version == 'latest'
           # hope for the best and hope it works eventually
           cmd << ' --retcode-passthrough'
@@ -286,6 +303,8 @@ module Kitchen
         debug("running driver #{name}")
         debug(diagnose)
 
+        return unless config[:run_salt_call]
+
         # config[:salt_version] can be 'latest' or 'x.y.z', 'YYYY.M.x' etc
         # error return codes are a mess in salt:
         #  https://github.com/saltstack/salt/pull/11337
@@ -403,6 +422,13 @@ module Kitchen
       end
 
       def prepare_dependencies
+        # Dependency scripts are bash scripts only
+        # Copying them clobbers the kitchen temp directory
+        # with a file named `kitchen`. If adding Windows
+        # support for dependencies, relocate into a
+        # sub-directory
+        return if windows_os?
+
         # upload scripts
         sandbox_scripts_path = File.join(sandbox_path, config[:salt_config], 'scripts')
         info("Preparing scripts into #{config[:salt_config]}/scripts")
@@ -453,7 +479,6 @@ module Kitchen
         instance_variables.each {|var| hash[var[1..-1]] = instance_variable_get(var) }
         hash.map{|k,v| [k.to_s.to_sym,v]}.to_h
       end
-
     end
   end
 end
